@@ -3,11 +3,12 @@
 #'   functions in ggplot2. Useful only when you want to call a geom_* function
 #'   without carrying about the arguments to put in aes(). Basic users of ggpubr
 #'   don't need this function.
+#' @inheritParams ggrepel::geom_text_repel
 #' @param geomfunc a ggplot2 function (e.g.: geom_point)
 #' @param data a data frame to be used for mapping
 #' @param position Position adjustment, either as a string, or the result of a
 #'   call to a position adjustment function.
-#' @param ... arguments accepeted by the function
+#' @param ... arguments accepted by the function
 #' @return return a plot if geomfunc!=Null or a list(option, mapping) if
 #'   geomfunc = NULL.
 #' @examples
@@ -40,7 +41,9 @@ geom_exec <- function (geomfunc = NULL, data = NULL,
     # error
     "ymin", "ymax", "xmin", "xmax",
     # text
-    "label", "hjust", "vjust", "fontface",
+    "label", "hjust", "vjust", "fontface", "angle", "family",
+    # text.repel
+    "segment.size", "force",
     # smooth
     "se", "level", "fullrange",
     "conf.int.level",
@@ -51,7 +54,9 @@ geom_exec <- function (geomfunc = NULL, data = NULL,
     # rug
     "sides",
     # segment
-    "arrow", "xend", "yend"
+    "arrow", "xend", "yend",
+    # stat_summary,
+    "fun.data", "fun.y", "fun.ymin", "fun.ymax"
 
   )
 
@@ -75,10 +80,11 @@ geom_exec <- function (geomfunc = NULL, data = NULL,
     option[["position"]] <- position
   option[["data"]] <- data
   if(is.null(geomfunc)){
-    return(list(option = option, mapping = mapping))
+   res <- list(option = option, mapping = mapping)
   }
   else{
     option[["mapping"]] <- do.call(ggplot2::aes_string, mapping)
-    return(do.call(geomfunc, option))
+    res <- do.call(geomfunc, option)
   }
+  res
 }
