@@ -2,7 +2,7 @@
 NULL
 #' Extract Legends from a ggplot object
 #' @description Extract the legend labels from a ggplot object.
-#' @param p an object of class ggplot.
+#' @param p an object of class ggplot or a list of ggplots. If p is a list, only the first legend is returned.
 #' @return an object of class gtable.
 #' @examples
 #' # Create a scatter plot
@@ -19,7 +19,32 @@ NULL
 #'
 #' @export
 get_legend <- function(p){
+
+  if(.is_list(p)){
+    continue <- TRUE
+    i <- 1
+    while(i <= length(p) & continue){
+      leg <- .get_legend(p[[i]])
+      if(!is.null(leg)) continue <- FALSE
+      i <- i+1
+    }
+  }
+  else{
+    leg <- .get_legend(p)
+  }
+  leg
+}
+
+
+
+# Return legend for one plot
+.get_legend <- function(p){
+
+  if(is.null(p)) return(NULL)
   tmp <- ggplot_gtable(ggplot_build(p))
   leg <- which(sapply(tmp$grobs, function(x) x$name) == "guide-box")
-  return(tmp$grobs[[leg]])
+  if(length(leg) > 0) leg <- tmp$grobs[[leg]]
+  else leg <- NULL
+  leg
 }
+
