@@ -616,10 +616,10 @@ p
       y <- intersect(y, colnames(data))
 
       if(.is_empty(y))
-        stop("Can't found the y elements in the data.")
+        stop("Can't find the y elements in the data.")
 
       else if(!.is_empty(not_found))
-        warning("Can't found the following element in the data: ",
+        warning("Can't find the following element in the data: ",
               .collapse(not_found))
     }
   }
@@ -809,6 +809,7 @@ p
                      label.select = NULL, repel = FALSE, label.rectangle = FALSE,
                      ggtheme = theme_pubr(),
                      fun_name = "", group = 1, # used only by ggline
+                     show.legend.text = NA,
                      ...)
   {
 
@@ -942,7 +943,8 @@ p
       .add_item(data = data, x = opts$x, y = opts$y,
                 label = label, label.select = label.select,
                 repel = repel, label.rectangle = label.rectangle, ggtheme = NULL,
-                grouping.vars = grouping.vars, facet.by = facet.by, position = geom.text.position)
+                grouping.vars = grouping.vars, facet.by = facet.by, position = geom.text.position,
+                show.legend = show.legend.text)
     p <- purrr::map(p,
                    function(p, label.opts){
                      . <- NULL
@@ -980,11 +982,23 @@ p
 
   if(is.null(p)) return(list())
 
-  res0 <- as.character(p$mapping)
-  res1 <- NULL
-  if(!.is_empty(p$layers))
-    res1 <- as.character(p$layers[[1]]$mapping)
-  c(res0, res1) %>%
+  . <- NULL
+
+  layer0.mapping <- as.character(p$mapping) %>% gsub("~", "", .)
+  layer0.mapping.labels <- p$mapping %>% names()
+  names(layer0.mapping) <- layer0.mapping.labels
+
+  layer1.mapping <- NULL
+
+  if(!.is_empty(p$layers)){
+    layer1.mapping <- p$layers[[1]]$mapping %>%
+      as.character() %>% gsub("~", "", .)
+    layer1.mapping.labels <- p$layers[[1]]$mapping %>%
+      names()
+    names(layer1.mapping) <- layer1.mapping.labels
+  }
+
+  c(layer0.mapping, layer1.mapping) %>%
     as.list()
 }
 
